==> haskell-mueval-0.9.4-52-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mueval.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mueval
version:              0.9.4
visibility:           public
id:                   mueval-0.9.4-IjUgIlNh4czGptb5h41E2P
key:                  mueval-0.9.4-IjUgIlNh4czGptb5h41E2P
license:              BSD-3-Clause
maintainer:           Terence Ng <stoicism03@gmail.com>
author:               Gwern <gwern@gwern.net>
homepage:             https://github.com/TerenceNg03/mueval#readme
synopsis:             Safely evaluate pure Haskell expressions
description:
    Mueval is a Haskell interpreter. It uses the GHC API to evaluate arbitrary Haskell expressions. Importantly, mueval takes many precautions to defang and avoid \"evil\" code.  It uses resource limits, whitelisted modules and Safe Haskell, special Show instances for IO, threads, processes, and changes of directory to sandbox the Haskell code. . It is, in short, intended to be a standalone version of Lambdabot'\''s famous evaluation functionality. For examples and explanations, please see the README file. . Mueval is POSIX-only.

category:             Development, Language
abi:                  34b6f17e9012bc5ae6edb8f9f6f48b2c
exposed:              True
exposed-modules:
    Mueval.ArgsParse Mueval.Context Mueval.Interpreter Mueval.Parallel
    Mueval.Resources

hidden-modules:       Paths_mueval
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mueval-0.9.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mueval-0.9.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mueval-0.9.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mueval
hs-libraries:         HSmueval-0.9.4-IjUgIlNh4czGptb5h41E2P
depends:
    Cabal-3.8.1.0 QuickCheck-2.14.3-5M5TotFyqMq9PCRuWSklwe
    base-4.17.2.1 containers-0.6.7 directory-1.3.7.1
    extensible-exceptions-0.1.1.4-AGheGT2ZUDiCzp52FHEfjQ
    filepath-1.4.2.2 hint-0.9.0.8-GXDiLRcCE0CBfLi49sjAFl mtl-2.2.2
    process-1.6.18.0 show-0.6-DRjWNPXwRHwDkx5r3o6Swd
    simple-reflect-0.3.3-Kct69QODYQA4F7issyqpIH unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-mueval/html/mueval.haddock
haddock-html:         /usr/share/doc/haskell-mueval/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mueval-0.9.4-53-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mueval.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mueval
version:              0.9.4
visibility:           public
id:                   mueval-0.9.4-MhT9RAe1irBDLEMR11XLO
key:                  mueval-0.9.4-MhT9RAe1irBDLEMR11XLO
license:              BSD-3-Clause
maintainer:           Terence Ng <stoicism03@gmail.com>
author:               Gwern <gwern@gwern.net>
homepage:             https://github.com/TerenceNg03/mueval#readme
synopsis:             Safely evaluate pure Haskell expressions
description:
    Mueval is a Haskell interpreter. It uses the GHC API to evaluate arbitrary Haskell expressions. Importantly, mueval takes many precautions to defang and avoid \"evil\" code.  It uses resource limits, whitelisted modules and Safe Haskell, special Show instances for IO, threads, processes, and changes of directory to sandbox the Haskell code. . It is, in short, intended to be a standalone version of Lambdabot'\''s famous evaluation functionality. For examples and explanations, please see the README file. . Mueval is POSIX-only.

category:             Development, Language
abi:                  ced31b8ad6cf19763996b5b7fe011693
exposed:              True
exposed-modules:
    Mueval.ArgsParse Mueval.Context Mueval.Interpreter Mueval.Parallel
    Mueval.Resources

hidden-modules:       Paths_mueval
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mueval-0.9.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mueval-0.9.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mueval-0.9.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mueval
hs-libraries:         HSmueval-0.9.4-MhT9RAe1irBDLEMR11XLO
depends:
    Cabal-3.8.1.0 QuickCheck-2.15.0.1-IOTPvrQgmtTKzJNacvV6kx
    base-4.17.2.1 containers-0.6.7 directory-1.3.7.1
    extensible-exceptions-0.1.1.4-AGheGT2ZUDiCzp52FHEfjQ
    filepath-1.4.2.2 hint-0.9.0.8-23eyYOGSmJHGML9GZ3U8kP mtl-2.2.2
    process-1.6.18.0 show-0.6-FHE1O5zJ7nGF2xGfY3KDhV
    simple-reflect-0.3.3-Kct69QODYQA4F7issyqpIH unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-mueval/html/mueval.haddock
haddock-html:         /usr/share/doc/haskell-mueval/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
